//
//  BluetoothManager.m
//  AsCameraScan
//
// Created by Asterisk.Inc on 2018/4/27.
// Copyright © 2018年 Asterisk.Inc. All rights reserved.
//

#import "BluetoothManager.h"
#import "BatteryView.h"
#import "System.h"

@implementation BluetoothManager{
    CBCentralManager *_centeralManager;
    AsFingerManager * _AsFingerManager;
    NSArray *_listArray;
    System  *_system;
}

static BluetoothManager *sharedBluetoothManager = nil;
+ (BluetoothManager *)sharedBluetoothManager{
    if (!sharedBluetoothManager) {
        sharedBluetoothManager = [[BluetoothManager alloc] init];
    }
    return sharedBluetoothManager;
}
- (instancetype)init
{
    self = [super init];
    if (self) {
        _system = [System sharedSystem];
        _AsFingerManager  = [AsFingerManager sharedAsFingerManager];
        _AsFingerManager.delegate = self;
        _listArray       = [[NSArray alloc] init];
        _battery = 0;
        _deviceBLEStatus = AsFingerDeviceBLEStatus_PowerOff;
        _centeralManager = [[CBCentralManager alloc]initWithDelegate:self queue:nil options:@{CBCentralManagerOptionShowPowerAlertKey:@NO}];
    }
    return self;
}
- (AsFinger *)currentConnectedBLE{
    return [_AsFingerManager getCurrentConnectedAsFinger];
}

-(int)getBattery{
    return _battery;
}

-(void)refresh{
    _listArray = [[NSMutableArray alloc] init];
    [_AsFingerManager startSearching];
}

-(void)connectBLEWithName:(NSString *)name{
    [_system setIsAutoConnected:YES];
    for (AsFinger *laser in _listArray) {
        if ([name isEqualToString:laser.name]) {
            laser.delegate = self;
            [laser connect];
            return;
        }
    }
}
-(void)disconnectBLEWithName:(NSString *)name{
    [_system setIsAutoConnected:NO];
    [[BatteryView sharedBatteryView] setHidden:YES];
    _battery = 0;
    if ([_AsFingerManager getCurrentConnectedAsFinger]) {
        [[_AsFingerManager getCurrentConnectedAsFinger] disconnect];
    }
}
- (void)startScan{
    [[_AsFingerManager getCurrentConnectedAsFinger] startScan];
}
- (void)stopScan{
    [[_AsFingerManager getCurrentConnectedAsFinger] stopScan];
}
- (void)getBLEBattery{
    [[_AsFingerManager getCurrentConnectedAsFinger] getBattery];
}
- (void)getBLEFirmVersion{
    [[_AsFingerManager getCurrentConnectedAsFinger] getFirmwareVersion];
}
- (void)sendData:(NSData *)data{
    [[_AsFingerManager getCurrentConnectedAsFinger] sendData:data];
}
- (NSString *)getAsFingerSDKVersion{
    return [AsFinger getSDKVersion];
}
#pragma mark - CBCentralManagerDelegate
-(void)centralManagerDidUpdateState:(CBCentralManager *)central{
    switch (central.state) {
        case CBManagerStatePoweredOn:{
            _deviceBLEStatus = AsFingerDeviceBLEStatus_PowerOn;
            if (self.delegate && [self.delegate respondsToSelector:@selector(whenUpdateDeviceBLEStatus:)]) {
                [self.delegate whenUpdateDeviceBLEStatus:AsFingerDeviceBLEStatus_PowerOn];
            }
        }
            break;
        case CBManagerStatePoweredOff: {
            _deviceBLEStatus = AsFingerDeviceBLEStatus_PowerOff;
            if (self.delegate && [self.delegate respondsToSelector:@selector(whenUpdateDeviceBLEStatus:)]) {
                [self.delegate whenUpdateDeviceBLEStatus:AsFingerDeviceBLEStatus_PowerOff];
            }
        }
            break;
        default:
            _deviceBLEStatus = AsFingerDeviceBLEStatus_Unsupported;
            if (self.delegate && [self.delegate respondsToSelector:@selector(whenUpdateDeviceBLEStatus:)]) {
                [self.delegate whenUpdateDeviceBLEStatus:AsFingerDeviceBLEStatus_Unsupported];
            }
            break;
    }
}

#pragma mark -AsFingerDelegate
- (void)whenAsFingerIsConnected:(BOOL)isConnected{
    if (!isConnected) {
        _battery = 0;
        [[BatteryView sharedBatteryView] setHidden:YES];
    } else {
        [_system setAsFingerName:[_AsFingerManager getCurrentConnectedAsFinger].name];
    }
    if (self.delegate && [self.delegate respondsToSelector:@selector(receivedBLEIsConnected:)]) {
        [self.delegate receivedBLEIsConnected:isConnected];
    }
}
- (void)receivedBarcodeData:(NSData *)barcodeData {
    if (self.delegate && [self.delegate respondsToSelector:@selector(whenReceivedBarcodeData:)]) {
        [self.delegate whenReceivedBarcodeData:barcodeData];
    }
}
- (void)receivedBattery:(int)battery{
     _battery = battery;
    if (self.delegate && [self.delegate respondsToSelector:@selector(receivedBLEBattery:)]) {
        [self.delegate receivedBLEBattery:battery];
    }
   
}
- (void)receivedFirmwareVersion:(NSString *)firmwareVersion{
    if (self.delegate && [self.delegate respondsToSelector:@selector(receivedBLEFirmVersion:)]) {
        [self.delegate receivedBLEFirmVersion:firmwareVersion];
    }
}

- (void)receivedData:(NSData *)data {
    if (self.delegate && [self.delegate respondsToSelector:@selector(receivedData:)]) {
        [self.delegate receivedData:data];
    }
}

#pragma mark - AsFingerManagerDelegate
-(void)whenReceivedAsFingerList:(NSArray *)asFingerList{
    _listArray = asFingerList;
    if (self.delegate && [self.delegate respondsToSelector:@selector(whenSearchedBLEList:)]) {
        dispatch_async(dispatch_get_main_queue(), ^{
            [self.delegate whenSearchedBLEList:self->_listArray];
        });
    }
    if ([[System sharedSystem] getIsAutoConnected] && [_AsFingerManager getCurrentConnectedAsFinger] &&  [_AsFingerManager getCurrentConnectedAsFinger] == nil) {
        for (AsFinger *laser in _listArray) {
            if ([laser.name isEqualToString:[[System sharedSystem] getAsFingerName]]) {
                laser.delegate = self;
                [laser connect];
                return;
            }
        }
    }else if([[System sharedSystem] getIsAutoConnected] && ![_AsFingerManager getCurrentConnectedAsFinger]){
        for (AsFinger *laser in _listArray) {
            if ([laser.name isEqualToString:[[System sharedSystem] getAsFingerName]]) {
                laser.delegate = self;
                [laser connect];
                return;
            }
        }
    }
}
@end
