//
//  BluetoothLightSet_VC.m
//  AsCameraScan
//
// Created by Asterisk.Inc on 2018/4/27.
// Copyright © 2018年 Asterisk.Inc. All rights reserved.
//

#import "BluetoothLightSet_VC.h"
#import "System.h"
#import "Until.h"
#import "BluetoothManager.h"

@interface BluetoothLightSet_VC ()<UITextFieldDelegate,UITableViewDelegate,UITableViewDataSource,BluetoothManagerDelegate>
@property (nonatomic, weak) IBOutlet UITextField *AsFingerUUIDText;
@property (nonatomic, weak) IBOutlet UITableView *blTableview;
@property (nonatomic, weak) IBOutlet UIButton *conBtn;
@property (weak, nonatomic) IBOutlet UILabel *pointerNameLabel;
@end

@implementation BluetoothLightSet_VC {
    System *system;
    UITapGestureRecognizer *singleTap;
    BluetoothManager * _bluetoothManager;
    CBPeripheral *_peripheral;
    NSArray *dataArray;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    UIButton *refreshBtn = [UIButton buttonWithType:UIButtonTypeCustom];
    [refreshBtn setImage:[UIImage imageNamed:@"refresh_200.png"] forState:UIControlStateNormal];
    refreshBtn.frame = CGRectMake(0, 0, 30, 30);
    [refreshBtn addTarget:self action:@selector(onClickRefresh:) forControlEvents:UIControlEventTouchUpInside];
    UIBarButtonItem * rightItem = [[UIBarButtonItem alloc] initWithCustomView:refreshBtn];
    self.navigationItem.rightBarButtonItem = rightItem;
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(applicationDidBecomeActive)
                                                 name:UIApplicationDidBecomeActiveNotification
                                               object:nil];
    
    
    system = [System sharedSystem];
    _bluetoothManager = [BluetoothManager sharedBluetoothManager];
    _bluetoothManager.delegate = self;
    dataArray  = [[NSMutableArray alloc] init];
    [self.blTableview reloadData];
    
    singleTap = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(singleTapConfirm)];
    
    if (![system getAsFingerName] || [[system getAsFingerName] isEqualToString:@""]) {
        self.AsFingerUUIDText.text = @"";
        [self.conBtn setTitle:NSLocalizedStringFromTable(@"Connect", @"InfoPlist",Nil) forState:UIControlStateNormal];
    }else{
        self.AsFingerUUIDText.text = [system getAsFingerName];
        if(_bluetoothManager.currentConnectedBLE) {
            [self.conBtn setTitle:NSLocalizedStringFromTable(@"Disconnect", @"InfoPlist",Nil) forState:UIControlStateNormal];
        }else{
            [self.conBtn setTitle:NSLocalizedStringFromTable(@"Connect", @"InfoPlist",Nil) forState:UIControlStateNormal];
        }
    }
    
    [self.conBtn addTarget:self action:@selector(onClickConBtn:) forControlEvents:UIControlEventTouchUpInside];
    if (_bluetoothManager.deviceBLEStatus != AsFingerDeviceBLEStatus_PowerOn) {
        UIAlertController* alert = [UIAlertController alertControllerWithTitle:NSLocalizedStringFromTable(@"Turn on Bluetooth before connecting to AsReader.", @"InfoPlist",Nil)
                                                                       message:nil
                                                                preferredStyle:UIAlertControllerStyleAlert];
        
        UIAlertAction* defaultAction = [UIAlertAction actionWithTitle:NSLocalizedStringFromTable(@"Settings", @"InfoPlist",Nil) style:UIAlertActionStyleDefault
                                                              handler:^(UIAlertAction * action) {
            NSURL *url = [NSURL URLWithString:@"App-Prefs:root"];
            NSDictionary *dic;
            [[UIApplication sharedApplication] openURL:url options:dic completionHandler:^(BOOL success) {
                
            }];
            
            
        }];
        UIAlertAction* cancelAction = [UIAlertAction actionWithTitle:NSLocalizedStringFromTable(@"Cancel", @"InfoPlist",Nil) style:UIAlertActionStyleDefault
                                                             handler:^(UIAlertAction * action) {
            
        }];
        [alert addAction:defaultAction];
        [alert addAction:cancelAction];
        [self presentViewController:alert animated:YES completion:nil];
    }else{
        [self refresh];
    }
}
- (void)applicationDidBecomeActive {
    _bluetoothManager.delegate = self;
    [_bluetoothManager refresh];
}

#pragma mark - Action
- (void)onClickRefresh:(id)sender {
    [self refresh];
}
- (void)onClickConBtn:(id)sender {
    if (_bluetoothManager.currentConnectedBLE) {
        [_bluetoothManager disconnectBLEWithName:_bluetoothManager.currentConnectedBLE.name];
    }else{
        for (AsFinger *laser in dataArray) {
            if ([self.AsFingerUUIDText.text isEqualToString:laser.name]) {
                [_bluetoothManager connectBLEWithName:laser.name];
                break;
            }
        }
    }
}
- (void)singleTapConfirm {
    [self.view removeGestureRecognizer:singleTap];
    [self.AsFingerUUIDText resignFirstResponder];
    if(_bluetoothManager.currentConnectedBLE){
        [_bluetoothManager disconnectBLEWithName:_bluetoothManager.currentConnectedBLE.name];
    }
}

#pragma mark - UITextFieldDelegate
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [dataArray count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    NSString *cellIdentifier = @"blDefaultCell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:cellIdentifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:cellIdentifier];
    }
    AsFinger *laser = [dataArray objectAtIndex:indexPath.row];
    NSString *str = laser.name;
    if (!str) {
        str = @"Unknown";
    }
    
    if ([laser isEqual:_bluetoothManager.currentConnectedBLE] && _bluetoothManager.currentConnectedBLE) {
        cell.accessoryType = UITableViewCellAccessoryCheckmark;
    }else{
        cell.accessoryType = UITableViewCellAccessoryNone;
    }
    cell.textLabel.text = str;
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    
    AsFinger *laser = [dataArray objectAtIndex:indexPath.row];
    if ([laser isEqual:_bluetoothManager.currentConnectedBLE] && _bluetoothManager.currentConnectedBLE) {
        [_bluetoothManager disconnectBLEWithName:laser.name];
    }else{
        AsFinger *laser = [dataArray objectAtIndex:indexPath.row];
        [_bluetoothManager connectBLEWithName:laser.name];
    }
}

#pragma mark - bluetoothManagerDelegate代理函数
- (void)whenUpdateDeviceBLEStatus:(AsFingerDeviceBLEStatus)status{
    switch (status) {
        case AsFingerDeviceBLEStatus_PowerOn:{
        }
            break;
        case AsFingerDeviceBLEStatus_PowerOff:
            break;
        default:
            break;
    }
}
- (void)receivedBLEIsConnected:(BOOL)isConnected{
    if (isConnected) {
        [self bluetoothConnect:YES];
    }else{
        [self bluetoothConnect:NO];
    }
}
- (void)whenSearchedBLEList:(NSArray *)BLEList{
    dispatch_async(dispatch_get_main_queue(), ^{
        self->dataArray = BLEList;
        [self.blTableview reloadData];
    });
}
#pragma mark - UITextFieldDelegate
-(void)textFieldDidBeginEditing:(UITextField *)textField {
    [self.view addGestureRecognizer:singleTap];
}

#pragma mark - custom
- (void)refresh{
    dataArray = [[NSMutableArray alloc] init];
    [_bluetoothManager refresh];
}

- (void)bluetoothConnect:(BOOL)isConnect{
    dispatch_async(dispatch_get_main_queue(), ^{
        if (isConnect == YES) {
            self.AsFingerUUIDText.text = [self->system getAsFingerName];
            [self.conBtn setTitle:NSLocalizedStringFromTable(@"Disconnect", @"InfoPlist",Nil) forState:UIControlStateNormal];
        }else{
            [self.conBtn setTitle:NSLocalizedStringFromTable(@"Connect", @"InfoPlist",Nil) forState:UIControlStateNormal];
        }
        [self.blTableview reloadData];
    });
}
@end

