//
//  DebugViewController.m
//  AsFinger
//
//  Created by mac on 2020/6/16.
//  Copyright © 2020 Asterisk. All rights reserved.
//

#import "DebugViewController.h"
#import "Until.h"
#import "BluetoothManager.h"

@interface DebugViewController ()<UITextViewDelegate, BluetoothManagerDelegate>
@property (strong, nonatomic) IBOutlet UITextView *debutTextView;
@property (strong, nonatomic) IBOutlet UITextView *sendTextView;
@property (strong, nonatomic) IBOutlet UIButton *sendButton;
@property (strong, nonatomic) IBOutlet UIButton *clearButton;
@end

@implementation DebugViewController {
    BluetoothManager *bluetoothManager;
    NSMutableString *dataString;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    bluetoothManager = [BluetoothManager sharedBluetoothManager];
    dataString = [[NSMutableString alloc] init];
    
    self.debutTextView.layer.masksToBounds = YES;
    self.debutTextView.layer.borderColor = [[UIColor lightGrayColor] CGColor];
    self.debutTextView.layer.borderWidth = 1;
    self.debutTextView.layer.cornerRadius = 5;
    
    self.sendTextView.layer.masksToBounds = YES;
    self.sendTextView.layer.borderColor = [[UIColor lightGrayColor] CGColor];
    self.sendTextView.layer.borderWidth = 1;
    self.sendTextView.layer.cornerRadius = 5;
    
    UITapGestureRecognizer *tap = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(viewBack)];
    [self.view addGestureRecognizer:tap];
}
- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:YES];
    bluetoothManager.delegate = self;
    if (bluetoothManager.currentConnectedBLE) {
        self.sendButton.userInteractionEnabled = YES;
        self.clearButton.userInteractionEnabled = YES;
        [self.sendButton setBackgroundColor:[UIColor colorWithRed:220 / 255.f green:12 / 255.f blue:33 /255.f alpha:1]];
        [self.clearButton setBackgroundColor:[UIColor colorWithRed:220 / 255.f green:12 / 255.f blue:33 /255.f alpha:1]];
    } else {
        self.sendButton.userInteractionEnabled = NO;
        self.clearButton.userInteractionEnabled = NO;
        [self.sendButton setBackgroundColor:[UIColor lightGrayColor]];
        [self.clearButton setBackgroundColor:[UIColor lightGrayColor]];
    }
}
- (IBAction)sendAction:(id)sender {
    [self.view endEditing:YES];
//    NSData *data = [[self.sendTextView.text uppercaseString] dataUsingEncoding:NSASCIIStringEncoding];
    NSData *data = [self.sendTextView.text  dataUsingEncoding:NSASCIIStringEncoding];

    [bluetoothManager sendData:data];
}
- (IBAction)clearAction:(id)sender {
    dataString = [NSMutableString string];
    self.debutTextView.text = @"";
}
- (void)viewBack {
    [self.view endEditing:YES];
}
- (BOOL)textView:(UITextView *)textView shouldChangeTextInRange:(NSRange)range replacementText:(NSString *)text{
    if ([text isEqualToString:@"\n"]){
        [textView resignFirstResponder];
    }
    return YES;
}
- (void)receivedData:(NSData *)data {
    NSMutableString* tmp = [[NSMutableString alloc] init];
    unsigned char* ptr= (unsigned char*) [data bytes];
    for(int i = 0; i < data.length; i++) {
        [tmp appendFormat:@"%02X", *ptr++ & 0xFF ];
    }
    NSString *barcode = [[NSString alloc] initWithData:data encoding:NSASCIIStringEncoding];
    if (dataString == nil || [@"" isEqualToString:dataString]) {
        [dataString appendString:barcode];
        [dataString appendString:@"\n"];
        [dataString appendString:[NSString stringWithFormat:@"DATA:%@",tmp]];
    } else {
        [dataString appendString:@"\n"];
        [dataString appendString:barcode];
        [dataString appendString:@"\n"];
        [dataString appendString:[NSString stringWithFormat:@"DATA:%@",tmp]];
    }
    dispatch_async(dispatch_get_main_queue(), ^{
        self.debutTextView.text = self->dataString;
    });
    
}

/*
 #pragma mark - Navigation
 
 // In a storyboard-based application, you will often want to do a little preparation before navigation
 - (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
 // Get the new view controller using [segue destinationViewController].
 // Pass the selected object to the new view controller.
 }
 */

@end
