//
//  InfomationViewController.m
//  AsFinger
//
//  Created by mac on 2020/6/16.
//  Copyright © 2020 Asterisk. All rights reserved.
//

#import "InfomationViewController.h"
#import "Until.h"
#import "BluetoothManager.h"

@interface InfomationViewController ()<UITableViewDelegate, UITableViewDataSource, BluetoothManagerDelegate>
@property (strong, nonatomic) IBOutlet UITableView *tableView;
@end

@implementation InfomationViewController{
    NSMutableArray *array;
    BluetoothManager *bluetoothManager;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    if (@available(iOS 15.0, *)) {
        self.tableView.sectionHeaderTopPadding = 0;
    }
    bluetoothManager = [BluetoothManager sharedBluetoothManager];
    bluetoothManager.delegate = self;
    array = [[NSMutableArray alloc] init];
    UIView *footView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 0, 0)];
    self.tableView.tableFooterView = footView;
    [array addObject:[NSString stringWithFormat:@"AsFingerSDK:\n%@", [bluetoothManager getAsFingerSDKVersion]]];
    [bluetoothManager getBLEBattery];
}
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView{
    return 1;
}
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return array.count;
}
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString *identifier = @"tableViewCell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:identifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:identifier];
    }
    cell.textLabel.text = [array objectAtIndex:indexPath.row];
    cell.textLabel.font = [UIFont systemFontOfSize:15];
    cell.textLabel.numberOfLines = 0;
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    return cell;
}

- (void)receivedBLEBattery:(int)battery {
    [bluetoothManager getBLEFirmVersion];
    [array addObject:[NSString stringWithFormat:@"Battery:\n%d%%", battery]];
    dispatch_async(dispatch_get_main_queue(), ^{
        [self.tableView reloadData];
    });
}

- (void)receivedBLEFirmVersion:(NSString *)version {
    if (![@"" isEqualToString:version]) {
        [array addObject:[NSString stringWithFormat:@"Firmware version:\n%@", version]];
        dispatch_async(dispatch_get_main_queue(), ^{
            [self.tableView reloadData];
        });
    }
}
@end
