//
//  MenuViewController.m
//  KAGO
//
//  Created by mac on 2019/1/22.
//  Copyright © 2019年 quzhonggen. All rights reserved.
//

#import "MenuViewController.h"
#import "BluetoothLightSet_VC.h"
#import "BluetoothManager.h"
#import "Until.h"
#import "BatteryView.h"

@interface MenuViewController ()<UITableViewDelegate, UITableViewDataSource, BluetoothManagerDelegate>
@property (strong, nonatomic) IBOutlet UIButton *startButton;
@property (strong, nonatomic) IBOutlet UIButton *stopButton;
@property (strong, nonatomic) IBOutlet UIButton *clearButton;
@property (strong, nonatomic) IBOutlet UITableView *tableView;
@property (strong, nonatomic) IBOutlet UIButton *logoButton;
@property (strong, nonatomic) IBOutlet UISegmentedControl *codeSegment;
@property (strong, nonatomic) IBOutlet UILabel *versionLabel;
@property (strong, nonatomic) IBOutlet UIView *batteryView;
@property (strong, nonatomic) NSMutableArray *dataArray;
@property (strong, nonatomic) NSTimer *batteryTimer;
@end

@implementation MenuViewController {
    BluetoothManager *bluetoothManager;
    NSStringEncoding encoding;
}

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:YES];
    bluetoothManager.delegate = self;
    if (bluetoothManager.currentConnectedBLE) {
        [self receivedBLEIsConnected:YES];
    } else {
        [self receivedBLEIsConnected:NO];
    }
}

- (void)viewWillDisappear:(BOOL)animated {
    [super viewWillDisappear:animated];
    [bluetoothManager stopScan];
    bluetoothManager.delegate = nil;
    if (self.batteryTimer) {
        [self.batteryTimer invalidate];
        self.batteryTimer = nil;
    }
}

- (void)viewDidLoad {
    [super viewDidLoad];
    if (@available(iOS 15.0, *)){
        NSDictionary *navbarTitleTextAttributes = [NSDictionary dictionaryWithObjectsAndKeys:
                                                   [UIColor blackColor],NSForegroundColorAttributeName,[UIFont boldSystemFontOfSize:17],NSFontAttributeName,
                                                   nil];
        UINavigationBarAppearance *appearance = [[UINavigationBarAppearance alloc] init];
        appearance.titleTextAttributes = navbarTitleTextAttributes;
        appearance.backgroundEffect = [UIBlurEffect effectWithStyle:UIBlurEffectStyleRegular];
        appearance.backgroundColor = [UIColor whiteColor];
        self.navigationController.navigationBar.scrollEdgeAppearance = appearance;
        self.navigationController.navigationBar.standardAppearance = appearance;
    }
    NSDictionary *navbarTitleTextAttributes = [NSDictionary dictionaryWithObjectsAndKeys:
                                               [UIColor blackColor],NSForegroundColorAttributeName,[UIFont boldSystemFontOfSize:17],NSFontAttributeName,
                                               nil];
    [self.navigationController.navigationBar setTitleTextAttributes:navbarTitleTextAttributes];
    
    if (@available(iOS 15.0, *)) {
        self.tableView.sectionHeaderTopPadding = 0;
    }
    
    self.dataArray = [[NSMutableArray alloc] init];
    encoding = NSASCIIStringEncoding;
    [self.codeSegment setSelectedSegmentIndex:0];
    bluetoothManager = [BluetoothManager sharedBluetoothManager];
    [self setUI];
}

#pragma mark - UI
- (void)setUI {
    self.startButton.layer.masksToBounds = YES;
    self.startButton.layer.cornerRadius = 5;
    self.stopButton.layer.masksToBounds = YES;
    self.stopButton.layer.cornerRadius = 5;
    self.clearButton.layer.masksToBounds = YES;
    self.clearButton.layer.cornerRadius = 5;
    self.versionLabel.text = [NSString stringWithFormat:@"Version: %@  Build: %@", [Until getAPPVersion], [Until getAPPBuild]];
    [self.batteryView addSubview:[BatteryView sharedBatteryView]];
}

#pragma mark - tableViewDelegate
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.dataArray.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"tableViewCell"];
    if(!cell){
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:@"tableViewCell"];
    }
    NSString *string = [self.dataArray objectAtIndex:indexPath.row];
    cell.textLabel.text = string;
    cell.textLabel.numberOfLines = 0;
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    return cell;
}

#pragma mark - Action
- (IBAction)startAction:(id)sender {
    [bluetoothManager startScan];
}

- (IBAction)stopAction:(id)sender {
    [bluetoothManager stopScan];
}

- (IBAction)clearAction:(id)sender {
    [self.dataArray removeAllObjects];
    [self.tableView reloadData];
}

- (IBAction)codeSegmentAction:(id)sender {
    UISegmentedControl *control = (UISegmentedControl *)sender;
    switch (control.selectedSegmentIndex) {
        case 0:
            encoding = NSASCIIStringEncoding;
            break;
        case 1:
            encoding = NSUTF8StringEncoding;
            break;
        case 2:
            encoding = NSShiftJISStringEncoding;
            break;
        default:
            encoding = NSASCIIStringEncoding;
            break;
    }
}

#pragma mark - bluetoothManagerDelegate
- (void)receivedBLEIsConnected:(BOOL)isConnected{
    bluetoothManager.delegate = self;
    dispatch_async(dispatch_get_main_queue(), ^{
        if (isConnected) {
            self.logoButton.enabled = YES;
            self.startButton.userInteractionEnabled = YES;
            [self.startButton setBackgroundColor:[UIColor colorWithRed:220 / 255.f green:12 / 255.f blue:33 /255.f alpha:1]];
            self.stopButton.userInteractionEnabled = YES;
            [self.stopButton setBackgroundColor:[UIColor colorWithRed:220 / 255.f green:12 / 255.f blue:33 /255.f alpha:1]];
            self.clearButton.userInteractionEnabled = YES;
            [self.clearButton setBackgroundColor:[UIColor colorWithRed:220 / 255.f green:12 / 255.f blue:33 /255.f alpha:1]];
            if (self.batteryTimer) {
                [self.batteryTimer invalidate];
                self.batteryTimer = nil;
            }
            self.batteryTimer = [NSTimer scheduledTimerWithTimeInterval:10 target:self selector:@selector(batteryTime) userInfo:nil repeats:YES];
            [[NSRunLoop currentRunLoop] addTimer:self.batteryTimer forMode:NSRunLoopCommonModes];
            [self.batteryTimer fire];

        } else {
            self.logoButton.enabled = NO;
            self.startButton.userInteractionEnabled = NO;
            [self.startButton setBackgroundColor:[UIColor lightGrayColor]];
            self.stopButton.userInteractionEnabled = NO;
            [self.stopButton setBackgroundColor:[UIColor lightGrayColor]];
            self.clearButton.userInteractionEnabled = NO;
            [self.clearButton setBackgroundColor:[UIColor lightGrayColor]];
            if (self.batteryTimer) {
                [self.batteryTimer invalidate];
                self.batteryTimer = nil;
            }
            [[BatteryView sharedBatteryView] setBatteryViewHidden:YES];
        }
    });
}
- (void)whenReceivedBarcodeData:(NSData *)barcodeData{
    NSLog(@"APPCode ==== %@", barcodeData);
    NSString *code = [[NSString alloc] initWithData:barcodeData encoding:encoding];
    if (!code) {
        dispatch_async(dispatch_get_main_queue(), ^{
            UIAlertController *alert = [UIAlertController alertControllerWithTitle:NSLocalizedStringFromTable(@"Please select another encoding mode for this barcode.", @"InfoPlist",Nil)
                                                                           message:nil
                                                                    preferredStyle:UIAlertControllerStyleAlert];

            UIAlertAction *defaultAction = [UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault
                                                                  handler:nil];
            [alert addAction:defaultAction];
            [self presentViewController:alert animated:YES completion:nil];
        });
        return;
    }
    [self.dataArray addObject:code];
    dispatch_async(dispatch_get_main_queue(), ^{
        [self.tableView reloadData];
        NSIndexPath *indexPath = [NSIndexPath indexPathForItem:self.dataArray.count - 1 inSection:0];
        [self.tableView scrollToRowAtIndexPath:indexPath atScrollPosition:UITableViewScrollPositionBottom animated:YES];
    });
}
- (void)receivedBLEBattery:(int)battery{
    [[BatteryView sharedBatteryView] setBatteryViewHidden:NO];
    [[BatteryView sharedBatteryView] setBatteryVolumeImage:battery];
}
- (void)batteryTime{
    [bluetoothManager getBLEBattery];
}

#pragma mark - Custom
- (NSString *)dataToStringMethod:(NSData *)data {
    NSMutableString *tagStinrg = [[NSMutableString alloc]init] ;
    unsigned char *ptr= (unsigned char *) [data bytes];
    for(int i = 0; i < data.length; i++) {
        [tagStinrg appendFormat:@"%02X", *ptr++ & 0xFF ];
    }
    NSString *string = [NSString stringWithFormat:@"%@", tagStinrg];
    return string;
}

@end
